# DESIGN AND OPERATION OF TRAFFIC AND TELECOMMUNICATION NETWORKS
# Ralf Borndoerfer, Fabio d'Andreagiovanni, Jonad Pulaj
# Freie Universitt Berlin, WS 2015/16
#
# Even degree problem
#
# Edges of an undirected graph are read from file "edges.dat" in format <1s,2s>
#
# <1s> origin city, e.g., "Ah"
# <2s> destination city, e.g., "Ut"
#
# Costs are read from file "cap.dat" in format in format <1s,2s,3n>
#
# <1s> origin city, e.g., "Ah"
# <2s> destination city, e.g., "Ut"
# <3n> cost, e.g., 18431
#
# List of cities
#
# Ah Arnhem
# Apd Apeldoorn
# Asd Amsterdam CS
# Asdz Amsterdam Zuid WTC
# Asn Assen
# Bd Breda
# Ehv Eindhoven
# Gn Groningen
# Gv Den Haag HS
# Gvc Den Haag CS
# Hgl Hengelo
# Hr Heerenveen
# Lls Lelystad Centrum
# Lw Leeuwarden
# Mt Maastricht
# Odzg Oldenzaal Grens
# Rsdg Rosendaal Grens
# Rtd Rotterdam CS
# Shl Schiphol
# Std Sittard
# Ut Utrecht CS
# Zl Zwolle
# Zvg Zevenaar Grens

# edges (undirected!)
set E := { read "edges.dat" as "<1s,2s>" comment "#" };

# costs
param c[E] := read "cap.dat" as "<1s,2s> 3n" comment "#";

# nodes
set V := proj(E,<1>) union proj(E,<2>);

# nodes of degree one
set R := { "Lw", "Gn", "Odzg", "Zvg", "Mt", "Rsdg" };

# neighborhoods of even nodes
set NE[<u> in V without R] := { <u,v> in E } union { <v,u> in E };

# edge subsets in neighborhoods of even nodes
set FE_Ah[]   := powerset(NE["Ah"]);
set FE_Apd[]  := powerset(NE["Apd"]);
set FE_Asd[]  := powerset(NE["Asd"]);
set FE_Asdz[] := powerset(NE["Asdz"]);
set FE_Asn[]  := powerset(NE["Asn"]);
set FE_Bd[]   := powerset(NE["Bd"]);
set FE_Ehv[]  := powerset(NE["Ehv"]);
set FE_Gv[]   := powerset(NE["Gv"]);
set FE_Gvc[]  := powerset(NE["Gvc"]);
set FE_Hgl[]  := powerset(NE["Hgl"]);
set FE_Hr[]   := powerset(NE["Hr"]);
set FE_Lls[]  := powerset(NE["Lls"]);
set FE_Rtd[]  := powerset(NE["Rtd"]);
set FE_Shl[]  := powerset(NE["Shl"]);
set FE_Std[]  := powerset(NE["Std"]);
set FE_Ut[]   := powerset(NE["Ut"]);
set FE_Zl[]   := powerset(NE["Zl"]);

# index sets of edge subsets in neighborhoods of even nodes
set IE_Ah     := indexset(FE_Ah);
set IE_Apd    := indexset(FE_Apd);
set IE_Asd    := indexset(FE_Asd);
set IE_Asdz   := indexset(FE_Asdz);
set IE_Asn    := indexset(FE_Asn);
set IE_Bd     := indexset(FE_Bd);
set IE_Ehv    := indexset(FE_Ehv);
set IE_Gv     := indexset(FE_Gv);
set IE_Gvc    := indexset(FE_Gvc);
set IE_Hgl    := indexset(FE_Hgl);
set IE_Hr     := indexset(FE_Hr);
set IE_Lls    := indexset(FE_Lls);
set IE_Rtd    := indexset(FE_Rtd);
set IE_Shl    := indexset(FE_Shl);
set IE_Std    := indexset(FE_Std);
set IE_Ut     := indexset(FE_Ut);
set IE_Zl     := indexset(FE_Zl);

# Utrecht
param Ut_deg := 2;

# variables

# objective

# constraints
